<?php

declare(strict_types=1);

namespace Drupal\style_options_media\Plugin\StyleOption;

use Drupal\Core\Ajax\AjaxHelperTrait;
use Drupal\Core\Form\FormStateInterface;
use Drupal\style_options\StyleOptionStyleTrait;
use Drupal\style_options\Plugin\StyleOptionPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Define the image attribute option plugin.
 *
 * @StyleOption(
 *   id = "background_media",
 *   label = @Translation("Background media")
 * )
 */
class BackgroundMedia extends StyleOptionPluginBase {

  use AjaxHelperTrait;
  use StyleOptionStyleTrait;

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $bg = new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('renderer'),
      $container->get('entity_type.manager')
    );
    return $bg;
  }

  /**
   * {@inheritDoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form['background_media'] = [
      '#type' => 'media_library',
      '#allowed_bundles' => ['image', 'video', 'remote_video'],
      '#title' => t('Background Media'),
      '#default_value' => NULL,
      '#description' => t('Select the media item to use as a background.'),
    ];
    return $form;
  }

  /**
   * {@inheritDoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $values = $form_state->cleanValues()->getValues();
    $this->setValues($values);
  }

  /**
   * {@inheritDoc}
   */
  public function build(array $build, $value = '') {
    if (empty($media = $this->getValue('background_media'))) {
      return $build;
    }

    $vb = $this->entityTypeManager->getViewBuilder('media');
    $media = $this->entityTypeManager->getStorage('media')->load($media);
    $build['style_options_background_media'] = $vb->view($media, 'background');
    return $build;
  }

}
